Index: talk/app/webrtc/webrtcsession.h |
diff --git a/talk/app/webrtc/webrtcsession.h b/talk/app/webrtc/webrtcsession.h |
index 30ebc1e49ee8dcc07e015e20f784f87d84af725e..e36364b107d21e8175736b07e1c00fa8724e802a 100644 |
--- a/talk/app/webrtc/webrtcsession.h |
+++ b/talk/app/webrtc/webrtcsession.h |
@@ -29,6 +29,7 @@ |
#define TALK_APP_WEBRTC_WEBRTCSESSION_H_ |
#include <string> |
+#include <vector> |
#include "talk/app/webrtc/datachannel.h" |
#include "talk/app/webrtc/dtmfsender.h" |
@@ -47,7 +48,6 @@ class BaseChannel; |
class ChannelManager; |
class DataChannel; |
class StatsReport; |
-class Transport; |
class VideoCapturer; |
class VideoChannel; |
class VoiceChannel; |
@@ -75,6 +75,8 @@ extern const char kSessionError[]; |
extern const char kSessionErrorDesc[]; |
extern const char kDtlsSetupFailureRtp[]; |
extern const char kDtlsSetupFailureRtcp[]; |
+extern const char kEnableBundleFailed[]; |
+ |
// Maximum number of received video streams that will be processed by webrtc |
// even if they are not signalled beforehand. |
extern const int kMaxUnsignalledRecvStreams; |
@@ -234,6 +236,18 @@ class WebRtcSession : public cricket::BaseSession, |
// This avoids exposing the internal structures used to track them. |
virtual bool GetTransportStats(cricket::SessionStats* stats); |
+ // Get stats for a specific channel |
+ bool GetChannelTransportStats(cricket::BaseChannel* ch, |
+ cricket::SessionStats* stats); |
+ |
+ // Caller owns returned identity |
+ virtual bool GetIdentity(const std::string& content_name, |
+ rtc::SSLIdentity** identity); |
pthatcher1
2015/08/10 20:40:16
Can you run "git cl format"? The style here looks
Taylor Brandstetter
2015/08/11 01:20:07
Done.
|
+ |
+ // Caller owns returned certificate |
+ virtual bool GetRemoteCertificate(const std::string& content_name, |
+ rtc::SSLCertificate** cert); |
+ |
// Implements DataChannelFactory. |
rtc::scoped_refptr<DataChannel> CreateDataChannel( |
const std::string& label, |
@@ -279,18 +293,10 @@ class WebRtcSession : public cricket::BaseSession, |
cricket::ContentSource source, |
std::string* error_desc); |
- |
- // Transport related callbacks, override from cricket::BaseSession. |
- virtual void OnTransportRequestSignaling(cricket::Transport* transport); |
- virtual void OnTransportConnecting(cricket::Transport* transport); |
- virtual void OnTransportWritable(cricket::Transport* transport); |
- virtual void OnTransportCompleted(cricket::Transport* transport); |
- virtual void OnTransportFailed(cricket::Transport* transport); |
- virtual void OnTransportProxyCandidatesReady( |
- cricket::TransportProxy* proxy, |
- const cricket::Candidates& candidates); |
- virtual void OnCandidatesAllocationDone(); |
- void OnTransportReceiving(cricket::Transport* transport) override; |
+ cricket::BaseChannel* GetChannel(const std::string& content_name); |
+ // Cause all the BaseChannels in the bundle group to have the same |
+ // transport channel. |
+ bool EnableBundle(const cricket::ContentGroup& bundle); |
// Enables media channels to allow sending of media. |
void EnableChannels(); |
@@ -310,7 +316,7 @@ class WebRtcSession : public cricket::BaseSession, |
bool UseCandidate(const IceCandidateInterface* candidate); |
// Deletes the corresponding channel of contents that don't exist in |desc|. |
// |desc| can be null. This means that all channels are deleted. |
- void RemoveUnusedChannelsAndTransports( |
+ void RemoveUnusedChannels( |
const cricket::SessionDescription* desc); |
// Allocates media channels based on the |desc|. If |desc| doesn't have |
@@ -360,9 +366,17 @@ class WebRtcSession : public cricket::BaseSession, |
const SessionDescriptionInterface* remote_desc, |
bool* valid); |
+ void OnTransportControllerConnectionStateChanged( |
+ cricket::TransportController::ConnectionState state); |
+ void OnTransportControllerReceiving(bool receiving); |
+ void OnTransportControllerCandidatesAllocationDone(); |
+ void OnTransportControllerCandidatesAllocationStarted(); |
pthatcher1
2015/08/10 20:40:17
While we're in here, can we change this to a Gathe
Taylor Brandstetter
2015/08/11 01:20:07
Done.
|
+ void OnTransportControllerCandidatesReady( |
pthatcher1
2015/08/10 20:40:16
And can we rename this to CandidatesGathered?
"ga
Taylor Brandstetter
2015/08/11 01:20:07
Done.
|
+ const std::string& transport_name, const cricket::Candidates& candidates); |
+ |
std::string GetSessionErrorMsg(); |
// Invoked when OnTransportCompleted is signaled to gather the usage |
// of IPv4/IPv6 as best connection. |
void ReportBestConnectionState(const cricket::TransportStats& stats); |
@@ -360,9 +366,17 @@ class WebRtcSession : public cricket::BaseSession, |
std::string GetSessionErrorMsg(); |
- // Invoked when OnTransportCompleted is signaled to gather the usage |
+ // Invoked when TransportController completion is signaled to gather the usage |
// of IPv4/IPv6 as best connection. |
void ReportBestConnectionState(const cricket::TransportStats& stats); |